@@ -6,7 +6,7 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class DeepinProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('Deepin', ProfileType.DesktopEnv)
+		super().__init__("Deepin", ProfileType.DesktopEnv)
 
 	@property
 	@override
@@ -14,7 +14,7 @@ class DeepinProfile(XorgProfile):
 		return [
 			"deepin",
 			"deepin-terminal",
-			"deepin-editor"
+			"deepin-editor",
 		]
 
 	@property
