@@ -1,26 +1,20 @@
-from typing import TYPE_CHECKING, override
+from typing import override
 
 from archinstall.default_profiles.desktops import SeatAccess
 from archinstall.default_profiles.profile import GreeterType, ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
+from archinstall.lib.translationhandler import tr
 from archinstall.tui.curses_menu import SelectMenu
 from archinstall.tui.menu_item import MenuItem, MenuItemGroup
 from archinstall.tui.result import ResultType
 from archinstall.tui.types import Alignment, FrameProperties
 
-if TYPE_CHECKING:
-	from collections.abc import Callable
-
-	from archinstall.lib.translationhandler import DeferredTranslation
-
-	_: Callable[[str], DeferredTranslation]
-
 
 class HyprlandProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('Hyprland', ProfileType.DesktopEnv)
+		super().__init__("Hyprland", ProfileType.DesktopEnv)
 
-		self.custom_settings = {'seat_access': None}
+		self.custom_settings = {"seat_access": None}
 
 	@property
 	@override
@@ -48,32 +42,32 @@ class HyprlandProfile(XorgProfile):
 	@property
 	@override
 	def services(self) -> list[str]:
-		if pref := self.custom_settings.get('seat_access', None):
+		if pref := self.custom_settings.get("seat_access", None):
 			return [pref]
 		return []
 
 	def _ask_seat_access(self) -> None:
 		# need to activate seat service and add to seat group
-		header = str(_('Hyprland needs access to your seat (collection of hardware devices i.e. keyboard, mouse, etc)'))
-		header += '\n' + str(_('Choose an option to give Hyprland access to your hardware')) + '\n'
+		header = tr("Hyprland needs access to your seat (collection of hardware devices i.e. keyboard, mouse, etc)")
+		header += "\n" + tr("Choose an option to give Hyprland access to your hardware") + "\n"
 
 		items = [MenuItem(s.value, value=s) for s in SeatAccess]
 		group = MenuItemGroup(items, sort_items=True)
 
-		default = self.custom_settings.get('seat_access', None)
+		default = self.custom_settings.get("seat_access", None)
 		group.set_default_by_value(default)
 
 		result = SelectMenu[SeatAccess](
 			group,
 			header=header,
 			allow_skip=False,
-			frame=FrameProperties.min(str(_('Seat access'))),
-			alignment=Alignment.CENTER
+			frame=FrameProperties.min(tr("Seat access")),
+			alignment=Alignment.CENTER,
 		).run()
 
 		if result.type_ == ResultType.Selection:
 			if result.item() is not None:
-				self.custom_settings['seat_access'] = result.get_value().value
+				self.custom_settings["seat_access"] = result.get_value().value
 
 	@override
 	def do_on_select(self) -> None:
