@@ -6,7 +6,7 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class PlasmaProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('KDE Plasma', ProfileType.DesktopEnv)
+		super().__init__("KDE Plasma", ProfileType.DesktopEnv)
 
 	@property
 	@override
@@ -17,7 +17,7 @@ class PlasmaProfile(XorgProfile):
 			"kate",
 			"dolphin",
 			"ark",
-			"plasma-workspace"
+			"plasma-workspace",
 		]
 
 	@property
