@@ -6,14 +6,14 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class QtileProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('Qtile', ProfileType.WindowMgr)
+		super().__init__("Qtile", ProfileType.WindowMgr)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		return [
-			'qtile',
-			'alacritty'
+			"qtile",
+			"alacritty",
 		]
 
 	@property
