@@ -6,15 +6,15 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class RiverProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('River', ProfileType.WindowMgr)
+		super().__init__("River", ProfileType.WindowMgr)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		return [
-			'foot',
-			'xdg-desktop-portal-wlr',
-			'river'
+			"foot",
+			"xdg-desktop-portal-wlr",
+			"river",
 		]
 
 	@property
