@@ -1,34 +1,28 @@
-from typing import TYPE_CHECKING, override
+from typing import override
 
 from archinstall.default_profiles.profile import Profile, ProfileType
-
-if TYPE_CHECKING:
-	from collections.abc import Callable
-
-	from archinstall.lib.translationhandler import DeferredTranslation
-
-	_: Callable[[str], DeferredTranslation]
+from archinstall.lib.translationhandler import tr
 
 
 class XorgProfile(Profile):
 	def __init__(
 		self,
-		name: str = 'Xorg',
+		name: str = "Xorg",
 		profile_type: ProfileType = ProfileType.Xorg,
-		advanced: bool = False
+		advanced: bool = False,
 	):
 		super().__init__(
 			name,
 			profile_type,
 			support_gfx_driver=True,
-			advanced=advanced
+			advanced=advanced,
 		)
 
 	@override
 	def preview_text(self) -> str:
-		text = str(_('Environment type: {}')).format(self.profile_type.value)
+		text = tr("Environment type: {}").format(self.profile_type.value)
 		if packages := self.packages_text():
-			text += f'\n{packages}'
+			text += f"\n{packages}"
 
 		return text
 
@@ -36,5 +30,5 @@ class XorgProfile(Profile):
 	@override
 	def packages(self) -> list[str]:
 		return [
-			'xorg-server'
+			"xorg-server",
 		]
