@@ -1,7 +1,8 @@
 from pathlib import Path
-from typing import TYPE_CHECKING, assert_never, override
+from typing import assert_never, override
 
 from archinstall.lib.models.device_model import SubvolumeModification
+from archinstall.lib.translationhandler import tr
 from archinstall.tui.curses_menu import EditMenu
 from archinstall.tui.result import ResultType
 from archinstall.tui.types import Alignment
@@ -9,31 +10,24 @@ from archinstall.tui.types import Alignment
 from ..menu.list_manager import ListManager
 from ..utils.util import prompt_dir
 
-if TYPE_CHECKING:
-	from collections.abc import Callable
-
-	from archinstall.lib.translationhandler import DeferredTranslation
-
-	_: Callable[[str], DeferredTranslation]
-
 
 class SubvolumeMenu(ListManager[SubvolumeModification]):
 	def __init__(
 		self,
 		btrfs_subvols: list[SubvolumeModification],
-		prompt: str | None = None
+		prompt: str | None = None,
 	):
 		self._actions = [
-			str(_('Add subvolume')),
-			str(_('Edit subvolume')),
-			str(_('Delete subvolume'))
+			tr("Add subvolume"),
+			tr("Edit subvolume"),
+			tr("Delete subvolume"),
 		]
 
 		super().__init__(
 			btrfs_subvols,
 			[self._actions[0]],
 			self._actions[1:],
-			prompt
+			prompt,
 		)
 
 	@override
@@ -42,10 +36,10 @@ class SubvolumeMenu(ListManager[SubvolumeModification]):
 
 	def _add_subvolume(self, preset: SubvolumeModification | None = None) -> SubvolumeModification | None:
 		result = EditMenu(
-			str(_('Subvolume name')),
+			tr("Subvolume name"),
 			alignment=Alignment.CENTER,
 			allow_skip=True,
-			default_text=str(preset.name) if preset else None
+			default_text=str(preset.name) if preset else None,
 		).input()
 
 		match result.type_:
@@ -54,17 +48,17 @@ class SubvolumeMenu(ListManager[SubvolumeModification]):
 			case ResultType.Selection:
 				name = result.text()
 			case ResultType.Reset:
-				raise ValueError('Unhandled result type')
+				raise ValueError("Unhandled result type")
 			case _:
 				assert_never(result.type_)
 
-		header = f"{_('Subvolume name')}: {name}\n"
+		header = f"{tr('Subvolume name')}: {name}\n"
 
 		path = prompt_dir(
-			str(_("Subvolume mountpoint")),
+			tr("Subvolume mountpoint"),
 			header=header,
 			allow_skip=True,
-			validate=False
+			validate=False,
 		)
 
 		if not path:
@@ -77,7 +71,7 @@ class SubvolumeMenu(ListManager[SubvolumeModification]):
 		self,
 		action: str,
 		entry: SubvolumeModification | None,
-		data: list[SubvolumeModification]
+		data: list[SubvolumeModification],
 	) -> list[SubvolumeModification]:
 		if action == self._actions[0]:  # add
 			new_subvolume = self._add_subvolume()
