@@ -1,5 +1,4 @@
 from pathlib import Path
-from typing import TYPE_CHECKING
 
 from archinstall.lib.args import arch_config_handler
 from archinstall.lib.disk.device_handler import device_handler
@@ -28,6 +27,7 @@ from archinstall.lib.models.device_model import (
 	_DeviceInfo,
 )
 from archinstall.lib.output import debug
+from archinstall.lib.translationhandler import tr
 from archinstall.tui.curses_menu import SelectMenu
 from archinstall.tui.menu_item import MenuItem, MenuItemGroup
 from archinstall.tui.result import ResultType
@@ -36,13 +36,6 @@ from archinstall.tui.types import Alignment, FrameProperties, Orientation, Previ
 from ..output import FormattedOutput
 from ..utils.util import prompt_dir
 
-if TYPE_CHECKING:
-	from collections.abc import Callable
-
-	from archinstall.lib.translationhandler import DeferredTranslation
-
-	_: Callable[[str], DeferredTranslation]
-
 
 def select_devices(preset: list[BDevice] | None = []) -> list[BDevice]:
 	def _preview_device_selection(item: MenuItem) -> str | None:
@@ -70,9 +63,9 @@ def select_devices(preset: list[BDevice] | None = []) -> list[BDevice]:
 		search_enabled=False,
 		multi=True,
 		preview_style=PreviewStyle.BOTTOM,
-		preview_size='auto',
-		preview_frame=FrameProperties.max('Partitions'),
-		allow_skip=True
+		preview_size="auto",
+		preview_frame=FrameProperties.max("Partitions"),
+		allow_skip=True,
 	).run()
 
 	match result.type_:
@@ -93,24 +86,24 @@ def select_devices(preset: list[BDevice] | None = []) -> list[BDevice]:
 
 def get_default_partition_layout(
 	devices: list[BDevice],
-	filesystem_type: FilesystemType | None = None
+	filesystem_type: FilesystemType | None = None,
 ) -> list[DeviceModification]:
 	if len(devices) == 1:
 		device_modification = suggest_single_disk_layout(
 			devices[0],
-			filesystem_type=filesystem_type
+			filesystem_type=filesystem_type,
 		)
 		return [device_modification]
 	else:
 		return suggest_multi_disk_layout(
 			devices,
-			filesystem_type=filesystem_type
+			filesystem_type=filesystem_type,
 		)
 
 
 def _manual_partitioning(
 	preset: list[DeviceModification],
-	devices: list[BDevice]
+	devices: list[BDevice],
 ) -> list[DeviceModification]:
 	modifications = []
 	for device in devices:
@@ -132,7 +125,7 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 	items = [
 		MenuItem(default_layout, value=default_layout),
 		MenuItem(manual_mode, value=manual_mode),
-		MenuItem(pre_mount_mode, value=pre_mount_mode)
+		MenuItem(pre_mount_mode, value=pre_mount_mode),
 	]
 	group = MenuItemGroup(items, sort_items=False)
 
@@ -143,8 +136,8 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 		group,
 		allow_skip=True,
 		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(str(_('Disk configuration type'))),
-		allow_reset=True
+		frame=FrameProperties.min(tr("Disk configuration type")),
+		allow_reset=True,
 	).run()
 
 	match result.type_:
@@ -156,10 +149,10 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 			selection = result.get_value()
 
 			if selection == pre_mount_mode:
-				output = 'You will use whatever drive-setup is mounted at the specified directory\n'
+				output = "You will use whatever drive-setup is mounted at the specified directory\n"
 				output += "WARNING: Archinstall won't check the suitability of this setup\n"
 
-				path = prompt_dir(str(_('Root mount directory')), output, allow_skip=True)
+				path = prompt_dir(tr("Root mount directory"), output, allow_skip=True)
 
 				if path is None:
 					return None
@@ -169,7 +162,7 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 				return DiskLayoutConfiguration(
 					config_type=DiskLayoutType.Pre_mount,
 					device_modifications=mods,
-					mountpoint=path
+					mountpoint=path,
 				)
 
 			preset_devices = [mod.device for mod in preset.device_modifications] if preset else []
@@ -183,7 +176,7 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 				if modifications:
 					return DiskLayoutConfiguration(
 						config_type=DiskLayoutType.Default,
-						device_modifications=modifications
+						device_modifications=modifications,
 					)
 			elif result.get_value() == manual_mode:
 				preset_mods = preset.device_modifications if preset else []
@@ -192,7 +185,7 @@ def select_disk_config(preset: DiskLayoutConfiguration | None = None) -> DiskLay
 				if modifications:
 					return DiskLayoutConfiguration(
 						config_type=DiskLayoutType.Manual,
-						device_modifications=modifications
+						device_modifications=modifications,
 					)
 
 	return None
@@ -213,8 +206,8 @@ def select_lvm_config(
 		group,
 		allow_reset=True,
 		allow_skip=True,
-		frame=FrameProperties.min(str(_('LVM configuration type'))),
-		alignment=Alignment.CENTER
+		frame=FrameProperties.min(tr("LVM configuration type")),
+		alignment=Alignment.CENTER,
 	).run()
 
 	match result.type_:
@@ -242,42 +235,42 @@ def _boot_partition(sector_size: SectorSize, using_gpt: bool) -> PartitionModifi
 		type=PartitionType.Primary,
 		start=start,
 		length=size,
-		mountpoint=Path('/boot'),
+		mountpoint=Path("/boot"),
 		fs_type=FilesystemType.Fat32,
-		flags=flags
+		flags=flags,
 	)
 
 
 def select_main_filesystem_format() -> FilesystemType:
 	items = [
-		MenuItem('btrfs', value=FilesystemType.Btrfs),
-		MenuItem('ext4', value=FilesystemType.Ext4),
-		MenuItem('xfs', value=FilesystemType.Xfs),
-		MenuItem('f2fs', value=FilesystemType.F2fs)
+		MenuItem("btrfs", value=FilesystemType.Btrfs),
+		MenuItem("ext4", value=FilesystemType.Ext4),
+		MenuItem("xfs", value=FilesystemType.Xfs),
+		MenuItem("f2fs", value=FilesystemType.F2fs),
 	]
 
 	if arch_config_handler.args.advanced:
-		items.append(MenuItem('ntfs', value=FilesystemType.Ntfs))
+		items.append(MenuItem("ntfs", value=FilesystemType.Ntfs))
 
 	group = MenuItemGroup(items, sort_items=False)
 	result = SelectMenu[FilesystemType](
 		group,
 		alignment=Alignment.CENTER,
-		frame=FrameProperties.min('Filesystem'),
-		allow_skip=False
+		frame=FrameProperties.min("Filesystem"),
+		allow_skip=False,
 	).run()
 
 	match result.type_:
 		case ResultType.Selection:
 			return result.get_value()
 		case _:
-			raise ValueError('Unhandled result type')
+			raise ValueError("Unhandled result type")
 
 
 def select_mount_options() -> list[str]:
-	prompt = str(_('Would you like to use compression or disable CoW?')) + '\n'
-	compression = str(_('Use compression'))
-	disable_cow = str(_('Disable Copy-on-Write'))
+	prompt = tr("Would you like to use compression or disable CoW?") + "\n"
+	compression = tr("Use compression")
+	disable_cow = tr("Disable Copy-on-Write")
 
 	items = [
 		MenuItem(compression, value=BtrfsMountOption.compress.value),
@@ -291,7 +284,7 @@ def select_mount_options() -> list[str]:
 		columns=2,
 		orientation=Orientation.HORIZONTAL,
 		search_enabled=False,
-		allow_skip=True
+		allow_skip=True,
 	).run()
 
 	match result.type_:
@@ -300,7 +293,7 @@ def select_mount_options() -> list[str]:
 		case ResultType.Selection:
 			return [result.get_value()]
 		case _:
-			raise ValueError('Unhandled result type')
+			raise ValueError("Unhandled result type")
 
 
 def process_root_partition_size(total_size: Size, sector_size: SectorSize) -> Size:
@@ -321,7 +314,7 @@ def process_root_partition_size(total_size: Size, sector_size: SectorSize) -> Si
 def suggest_single_disk_layout(
 	device: BDevice,
 	filesystem_type: FilesystemType | None = None,
-	separate_home: bool | None = None
+	separate_home: bool | None = None,
 ) -> DeviceModification:
 	if not filesystem_type:
 		filesystem_type = select_main_filesystem_format()
@@ -332,7 +325,7 @@ def suggest_single_disk_layout(
 	min_size_to_allow_home_part = Size(64, Unit.GiB, sector_size)
 
 	if filesystem_type == FilesystemType.Btrfs:
-		prompt = str(_('Would you like to use BTRFS subvolumes with a default structure?')) + '\n'
+		prompt = tr("Would you like to use BTRFS subvolumes with a default structure?") + "\n"
 		group = MenuItemGroup.yes_no()
 		group.set_focus_by_value(MenuItem.yes().value)
 		result = SelectMenu[bool](
@@ -341,7 +334,7 @@ def suggest_single_disk_layout(
 			alignment=Alignment.CENTER,
 			columns=2,
 			orientation=Orientation.HORIZONTAL,
-			allow_skip=False
+			allow_skip=False,
 		).run()
 
 		using_subvolumes = result.item() == MenuItem.yes()
@@ -364,16 +357,12 @@ def suggest_single_disk_layout(
 	boot_partition = _boot_partition(sector_size, using_gpt)
 	device_modification.add_partition(boot_partition)
 
-	if (
-		separate_home is False
-		or using_subvolumes
-		or total_size < min_size_to_allow_home_part
-	):
+	if separate_home is False or using_subvolumes or total_size < min_size_to_allow_home_part:
 		using_home_partition = False
 	elif separate_home:
 		using_home_partition = True
 	else:
-		prompt = str(_('Would you like to create a separate partition for /home?')) + '\n'
+		prompt = tr("Would you like to create a separate partition for /home?") + "\n"
 		group = MenuItemGroup.yes_no()
 		group.set_focus_by_value(MenuItem.yes().value)
 		result = SelectMenu(
@@ -382,7 +371,7 @@ def suggest_single_disk_layout(
 			orientation=Orientation.HORIZONTAL,
 			columns=2,
 			alignment=Alignment.CENTER,
-			allow_skip=False
+			allow_skip=False,
 		).run()
 
 		using_home_partition = result.item() == MenuItem.yes()
@@ -401,9 +390,9 @@ def suggest_single_disk_layout(
 		type=PartitionType.Primary,
 		start=root_start,
 		length=root_length,
-		mountpoint=Path('/') if not using_subvolumes else None,
+		mountpoint=Path("/") if not using_subvolumes else None,
 		fs_type=filesystem_type,
-		mount_options=mount_options
+		mount_options=mount_options,
 	)
 
 	device_modification.add_partition(root_partition)
@@ -413,10 +402,10 @@ def suggest_single_disk_layout(
 		# https://unix.stackexchange.com/questions/246976/btrfs-subvolume-uuid-clash
 		# https://github.com/classy-giraffe/easy-arch/blob/main/easy-arch.sh
 		subvolumes = [
-			SubvolumeModification(Path('@'), Path('/')),
-			SubvolumeModification(Path('@home'), Path('/home')),
-			SubvolumeModification(Path('@log'), Path('/var/log')),
-			SubvolumeModification(Path('@pkg'), Path('/var/cache/pacman/pkg'))
+			SubvolumeModification(Path("@"), Path("/")),
+			SubvolumeModification(Path("@home"), Path("/home")),
+			SubvolumeModification(Path("@log"), Path("/var/log")),
+			SubvolumeModification(Path("@pkg"), Path("/var/cache/pacman/pkg")),
 		]
 		root_partition.btrfs_subvols = subvolumes
 	elif using_home_partition:
@@ -435,10 +424,10 @@ def suggest_single_disk_layout(
 			type=PartitionType.Primary,
 			start=home_start,
 			length=home_length,
-			mountpoint=Path('/home'),
+			mountpoint=Path("/home"),
 			fs_type=filesystem_type,
 			mount_options=mount_options,
-			flags=flags
+			flags=flags,
 		)
 		device_modification.add_partition(home_partition)
 
@@ -447,7 +436,7 @@ def suggest_single_disk_layout(
 
 def suggest_multi_disk_layout(
 	devices: list[BDevice],
-	filesystem_type: FilesystemType | None = None
+	filesystem_type: FilesystemType | None = None,
 ) -> list[DeviceModification]:
 	if not devices:
 		return []
@@ -478,11 +467,11 @@ def suggest_multi_disk_layout(
 	root_device: BDevice | None = sorted_delta[0][0]
 
 	if home_device is None or root_device is None:
-		text = str(_('The selected drives do not have the minimum capacity required for an automatic suggestion\n'))
-		text += str(_('Minimum capacity for /home partition: {}GiB\n').format(min_home_partition_size.format_size(Unit.GiB)))
-		text += str(_('Minimum capacity for Arch Linux partition: {}GiB').format(desired_root_partition_size.format_size(Unit.GiB)))
+		text = tr("The selected drives do not have the minimum capacity required for an automatic suggestion\n")
+		text += tr("Minimum capacity for /home partition: {}GiB\n").format(min_home_partition_size.format_size(Unit.GiB))
+		text += tr("Minimum capacity for Arch Linux partition: {}GiB").format(desired_root_partition_size.format_size(Unit.GiB))
 
-		items = [MenuItem(str(_('Continue')))]
+		items = [MenuItem(tr("Continue"))]
 		group = MenuItemGroup(items)
 		SelectMenu(group).run()
 
@@ -491,11 +480,11 @@ def suggest_multi_disk_layout(
 	if filesystem_type == FilesystemType.Btrfs:
 		mount_options = select_mount_options()
 
-	device_paths = ', '.join([str(d.device_info.path) for d in devices])
+	device_paths = ", ".join([str(d.device_info.path) for d in devices])
 
-	debug(f'Suggesting multi-disk-layout for devices: {device_paths}')
-	debug(f'/root: {root_device.device_info.path}')
-	debug(f'/home: {home_device.device_info.path}')
+	debug(f"Suggesting multi-disk-layout for devices: {device_paths}")
+	debug(f"/root: {root_device.device_info.path}")
+	debug(f"/home: {home_device.device_info.path}")
 
 	root_device_modification = DeviceModification(root_device, wipe=True)
 	home_device_modification = DeviceModification(home_device, wipe=True)
@@ -523,9 +512,9 @@ def suggest_multi_disk_layout(
 		type=PartitionType.Primary,
 		start=root_start,
 		length=root_length,
-		mountpoint=Path('/'),
+		mountpoint=Path("/"),
 		mount_options=mount_options,
-		fs_type=filesystem_type
+		fs_type=filesystem_type,
 	)
 	root_device_modification.add_partition(root_partition)
 
@@ -545,10 +534,10 @@ def suggest_multi_disk_layout(
 		type=PartitionType.Primary,
 		start=home_start,
 		length=home_length,
-		mountpoint=Path('/home'),
+		mountpoint=Path("/home"),
 		mount_options=mount_options,
 		fs_type=filesystem_type,
-		flags=flags
+		flags=flags,
 	)
 	home_device_modification.add_partition(home_partition)
 
@@ -558,10 +547,10 @@ def suggest_multi_disk_layout(
 def suggest_lvm_layout(
 	disk_config: DiskLayoutConfiguration,
 	filesystem_type: FilesystemType | None = None,
-	vg_grp_name: str = 'ArchinstallVg',
+	vg_grp_name: str = "ArchinstallVg",
 ) -> LvmConfiguration:
 	if disk_config.config_type != DiskLayoutType.Default:
-		raise ValueError('LVM suggested volumes are only available for default partitioning')
+		raise ValueError("LVM suggested volumes are only available for default partitioning")
 
 	using_subvolumes = False
 	btrfs_subvols = []
@@ -572,7 +561,7 @@ def suggest_lvm_layout(
 		filesystem_type = select_main_filesystem_format()
 
 	if filesystem_type == FilesystemType.Btrfs:
-		prompt = str(_('Would you like to use BTRFS subvolumes with a default structure?')) + '\n'
+		prompt = tr("Would you like to use BTRFS subvolumes with a default structure?") + "\n"
 		group = MenuItemGroup.yes_no()
 		group.set_focus_by_value(MenuItem.yes().value)
 
@@ -591,10 +580,10 @@ def suggest_lvm_layout(
 
 	if using_subvolumes:
 		btrfs_subvols = [
-			SubvolumeModification(Path('@'), Path('/')),
-			SubvolumeModification(Path('@home'), Path('/home')),
-			SubvolumeModification(Path('@log'), Path('/var/log')),
-			SubvolumeModification(Path('@pkg'), Path('/var/cache/pacman/pkg'))
+			SubvolumeModification(Path("@"), Path("/")),
+			SubvolumeModification(Path("@home"), Path("/home")),
+			SubvolumeModification(Path("@log"), Path("/var/log")),
+			SubvolumeModification(Path("@pkg"), Path("/var/cache/pacman/pkg")),
 		]
 
 		home_volume = False
@@ -610,7 +599,7 @@ def suggest_lvm_layout(
 				other_part.append(part)
 
 	if not boot_part:
-		raise ValueError('Unable to find boot partition in partition modifications')
+		raise ValueError("Unable to find boot partition in partition modifications")
 
 	total_vol_available = sum(
 		[p.length for p in other_part],
@@ -623,12 +612,12 @@ def suggest_lvm_layout(
 
 	root_vol = LvmVolume(
 		status=LvmVolumeStatus.Create,
-		name='root',
+		name="root",
 		fs_type=filesystem_type,
 		length=root_vol_size,
-		mountpoint=Path('/'),
+		mountpoint=Path("/"),
 		btrfs_subvols=btrfs_subvols,
-		mount_options=mount_options
+		mount_options=mount_options,
 	)
 
 	lvm_vol_group.volumes.append(root_vol)
@@ -636,10 +625,10 @@ def suggest_lvm_layout(
 	if home_volume:
 		home_vol = LvmVolume(
 			status=LvmVolumeStatus.Create,
-			name='home',
+			name="home",
 			fs_type=filesystem_type,
 			length=home_vol_size,
-			mountpoint=Path('/home'),
+			mountpoint=Path("/home"),
 		)
 
 		lvm_vol_group.volumes.append(home_vol)
