@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
+from archinstall.lib.translationhandler import tr
 from archinstall.tui.curses_menu import SelectMenu
 from archinstall.tui.menu_item import MenuItem, MenuItemGroup
 from archinstall.tui.result import ResultType
@@ -10,13 +9,6 @@ from archinstall.tui.types import Alignment, FrameProperties, FrameStyle, Orient
 from ..hardware import GfxDriver, SysInfo
 from ..models.bootloader import Bootloader
 
-if TYPE_CHECKING:
-	from collections.abc import Callable
-
-	from archinstall.lib.translationhandler import DeferredTranslation
-
-	_: Callable[[str], DeferredTranslation]
-
 
 def select_kernel(preset: list[str] = []) -> list[str]:
 	"""
@@ -40,8 +32,8 @@ def select_kernel(preset: list[str] = []) -> list[str]:
 		allow_skip=True,
 		allow_reset=True,
 		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(str(_('Kernel'))),
-		multi=True
+		frame=FrameProperties.min(tr("Kernel")),
+		multi=True,
 	).run()
 
 	match result.type_:
@@ -58,7 +50,7 @@ def ask_for_bootloader(preset: Bootloader | None) -> Bootloader | None:
 	if not SysInfo.has_uefi():
 		options = [Bootloader.Grub, Bootloader.Limine]
 		default = Bootloader.Grub
-		header = str(_('UEFI is not detected and some options are disabled'))
+		header = tr("UEFI is not detected and some options are disabled")
 	else:
 		options = [b for b in Bootloader]
 		default = Bootloader.Systemd
@@ -73,8 +65,8 @@ def ask_for_bootloader(preset: Bootloader | None) -> Bootloader | None:
 		group,
 		header=header,
 		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(str(_('Bootloader'))),
-		allow_skip=True
+		frame=FrameProperties.min(tr("Bootloader")),
+		allow_skip=True,
 	).run()
 
 	match result.type_:
@@ -83,11 +75,11 @@ def ask_for_bootloader(preset: Bootloader | None) -> Bootloader | None:
 		case ResultType.Selection:
 			return result.get_value()
 		case ResultType.Reset:
-			raise ValueError('Unhandled result type')
+			raise ValueError("Unhandled result type")
 
 
 def ask_for_uki(preset: bool = True) -> bool:
-	prompt = str(_('Would you like to use unified kernel images?')) + '\n'
+	prompt = tr("Would you like to use unified kernel images?") + "\n"
 
 	group = MenuItemGroup.yes_no()
 	group.set_focus_by_value(preset)
@@ -98,7 +90,7 @@ def ask_for_uki(preset: bool = True) -> bool:
 		columns=2,
 		orientation=Orientation.HORIZONTAL,
 		alignment=Alignment.CENTER,
-		allow_skip=True
+		allow_skip=True,
 	).run()
 
 	match result.type_:
@@ -107,7 +99,7 @@ def ask_for_uki(preset: bool = True) -> bool:
 		case ResultType.Selection:
 			return result.item() == MenuItem.yes()
 		case ResultType.Reset:
-			raise ValueError('Unhandled result type')
+			raise ValueError("Unhandled result type")
 
 
 def select_driver(options: list[GfxDriver] = [], preset: GfxDriver | None = None) -> GfxDriver | None:
@@ -128,22 +120,22 @@ def select_driver(options: list[GfxDriver] = [], preset: GfxDriver | None = None
 	if preset is not None:
 		group.set_focus_by_value(preset)
 
-	header = ''
+	header = ""
 	if SysInfo.has_amd_graphics():
-		header += str(_('For the best compatibility with your AMD hardware, you may want to use either the all open-source or AMD / ATI options.')) + '\n'
+		header += tr("For the best compatibility with your AMD hardware, you may want to use either the all open-source or AMD / ATI options.") + "\n"
 	if SysInfo.has_intel_graphics():
-		header += str(_('For the best compatibility with your Intel hardware, you may want to use either the all open-source or Intel options.\n'))
+		header += tr("For the best compatibility with your Intel hardware, you may want to use either the all open-source or Intel options.\n")
 	if SysInfo.has_nvidia_graphics():
-		header += str(_('For the best compatibility with your Nvidia hardware, you may want to use the Nvidia proprietary driver.\n'))
+		header += tr("For the best compatibility with your Nvidia hardware, you may want to use the Nvidia proprietary driver.\n")
 
 	result = SelectMenu[GfxDriver](
 		group,
 		header=header,
 		allow_skip=True,
 		allow_reset=True,
-		preview_size='auto',
+		preview_size="auto",
 		preview_style=PreviewStyle.BOTTOM,
-		preview_frame=FrameProperties(str(_('Info')), h_frame_style=FrameStyle.MIN)
+		preview_frame=FrameProperties(tr("Info"), h_frame_style=FrameStyle.MIN),
 	).run()
 
 	match result.type_:
@@ -161,7 +153,7 @@ def ask_for_swap(preset: bool = True) -> bool:
 	else:
 		default_item = MenuItem.no()
 
-	prompt = str(_('Would you like to use swap on zram?')) + '\n'
+	prompt = tr("Would you like to use swap on zram?") + "\n"
 
 	group = MenuItemGroup.yes_no()
 	group.set_focus_by_value(default_item)
@@ -172,7 +164,7 @@ def ask_for_swap(preset: bool = True) -> bool:
 		columns=2,
 		orientation=Orientation.HORIZONTAL,
 		alignment=Alignment.CENTER,
-		allow_skip=True
+		allow_skip=True,
 	).run()
 
 	match result.type_:
@@ -181,6 +173,6 @@ def ask_for_swap(preset: bool = True) -> bool:
 		case ResultType.Selection:
 			return result.item() == MenuItem.yes()
 		case ResultType.Reset:
-			raise ValueError('Unhandled result type')
+			raise ValueError("Unhandled result type")
 
 	return preset
