@@ -6,10 +6,7 @@ import json
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, override
-
-if TYPE_CHECKING:
-	_: Any
+from typing import override
 
 
 @dataclass
@@ -23,7 +20,7 @@ class Language:
 	@property
 	def display_name(self) -> str:
 		name = self.name_en
-		return f'{name} ({self.translation_percent}%)'
+		return f"{name} ({self.translation_percent}%)"
 
 	def is_match(self, lang_or_translated_lang: str) -> bool:
 		if self.name_en == lang_or_translated_lang:
@@ -38,8 +35,8 @@ class Language:
 
 class TranslationHandler:
 	def __init__(self) -> None:
-		self._base_pot = 'base.pot'
-		self._languages = 'languages.json'
+		self._base_pot = "base.pot"
+		self._languages = "languages.json"
 
 		self._total_messages = self._get_total_active_messages()
 		self._translated_languages = self._get_translations()
@@ -58,17 +55,17 @@ class TranslationHandler:
 		languages = []
 
 		for short_form in defined_languages:
-			mapping_entry: dict[str, str] = next(filter(lambda x: x['abbr'] == short_form, mappings))
-			abbr = mapping_entry['abbr']
-			lang = mapping_entry['lang']
-			translated_lang = mapping_entry.get('translated_lang', None)
+			mapping_entry: dict[str, str] = next(filter(lambda x: x["abbr"] == short_form, mappings))
+			abbr = mapping_entry["abbr"]
+			lang = mapping_entry["lang"]
+			translated_lang = mapping_entry.get("translated_lang", None)
 
 			try:
 				# get a translation for a specific language
-				translation = gettext.translation('base', localedir=self._get_locales_dir(), languages=(abbr, lang))
+				translation = gettext.translation("base", localedir=self._get_locales_dir(), languages=(abbr, lang))
 
 				# calculate the percentage of total translated text to total number of messages
-				if abbr == 'en':
+				if abbr == "en":
 					percent = 100
 				else:
 					num_translations = self._get_catalog_size(translation)
@@ -108,9 +105,9 @@ class TranslationHandler:
 		Get total messages that could be translated
 		"""
 		locales = self._get_locales_dir()
-		with open(f'{locales}/{self._base_pot}') as fp:
+		with open(f"{locales}/{self._base_pot}") as fp:
 			lines = fp.readlines()
-			msgid_lines = [line for line in lines if 'msgid' in line]
+			msgid_lines = [line for line in lines if "msgid" in line]
 
 		return len(msgid_lines) - 1  # don't count the first line which contains the metadata
 
@@ -121,7 +118,7 @@ class TranslationHandler:
 		try:
 			return next(filter(lambda x: x.name_en == name, self._translated_languages))
 		except Exception:
-			raise ValueError(f'No language with name found: {name}')
+			raise ValueError(f"No language with name found: {name}")
 
 	def get_language_by_abbr(self, abbr: str) -> Language:
 		"""
@@ -136,6 +133,7 @@ class TranslationHandler:
 		"""
 		Set the provided language as the current translation
 		"""
+		# The install() call has the side effect of assigning GNUTranslations.gettext to builtins._
 		language.translation.install()
 
 	def _get_locales_dir(self) -> Path:
@@ -143,7 +141,7 @@ class TranslationHandler:
 		Get the locales directory path
 		"""
 		cur_path = Path(__file__).parent.parent
-		locales_dir = Path.joinpath(cur_path, 'locales')
+		locales_dir = Path.joinpath(cur_path, "locales")
 		return locales_dir
 
 	def _provided_translations(self) -> list[str]:
@@ -155,13 +153,13 @@ class TranslationHandler:
 
 		translation_files = []
 		for filename in filenames:
-			if len(filename) == 2 or filename in ['pt_BR', 'zh-CN', 'zh-TW']:
+			if len(filename) == 2 or filename in ["pt_BR", "zh-CN", "zh-TW"]:
 				translation_files.append(filename)
 
 		return translation_files
 
 
-class DeferredTranslation:
+class _DeferredTranslation:
 	def __init__(self, message: str):
 		self.message = message
 
@@ -170,10 +168,12 @@ class DeferredTranslation:
 
 	@override
 	def __str__(self) -> str:
-		translate = _
-		if translate is DeferredTranslation:
+		if builtins._ is _DeferredTranslation:  # type: ignore[attr-defined]
 			return self.message
-		return translate(self.message)
+
+		# builtins._ is changed from _DeferredTranslation to GNUTranslations.gettext after
+		# Language.activate() is called
+		return builtins._(self.message)  # type: ignore[attr-defined]
 
 	def __lt__(self, other) -> bool:
 		return self.message < other
@@ -181,17 +181,19 @@ class DeferredTranslation:
 	def __gt__(self, other) -> bool:
 		return self.message > other
 
-	def __add__(self, other) -> DeferredTranslation:
+	def __add__(self, other) -> _DeferredTranslation:
 		if isinstance(other, str):
-			other = DeferredTranslation(other)
+			other = _DeferredTranslation(other)
 
 		concat = self.message + other.message
-		return DeferredTranslation(concat)
-
-	def format(self, *args) -> str:
-		return self.message.format(*args)
+		return _DeferredTranslation(concat)
 
 
-builtins._ = DeferredTranslation  # type: ignore[attr-defined]
+def tr(message: str) -> str:
+	return str(_DeferredTranslation(message))
+
+
+builtins._ = _DeferredTranslation  # type: ignore[attr-defined]
+
 
 translation_handler = TranslationHandler()
