@@ -24,17 +24,18 @@ def perform_installation(mountpoint: Path) -> None:
 
 	disk_config = config.disk_config
 	disk_encryption = config.disk_encryption
+	mountpoint = disk_config.mountpoint if disk_config.mountpoint else mountpoint
 
 	with Installer(
 		mountpoint,
 		disk_config,
 		disk_encryption=disk_encryption,
-		kernels=config.kernels
+		kernels=config.kernels,
 	) as installation:
 		# Strap in the base system, add a boot loader and configure
 		# some other minor details as specified by this profile and user.
 		if installation.minimal_installation():
-			installation.set_hostname('minimal-arch')
+			installation.set_hostname("minimal-arch")
 			installation.add_bootloader(Bootloader.Systemd)
 
 			network_config = config.network_config
@@ -42,15 +43,15 @@ def perform_installation(mountpoint: Path) -> None:
 			if network_config:
 				network_config.install_network_config(
 					installation,
-					config.profile_config
+					config.profile_config,
 				)
 
-			installation.add_additional_packages(['nano', 'wget', 'git'])
+			installation.add_additional_packages(["nano", "wget", "git"])
 
 			profile_config = ProfileConfiguration(MinimalProfile())
 			profile_handler.install_profile_config(installation, profile_config)
 
-			user = User('devel', Password(plaintext='devel'), False)
+			user = User("devel", Password(plaintext="devel"), False)
 			installation.create_users(user)
 
 	# Once this is done, we output some useful information to the user
@@ -81,13 +82,13 @@ def _minimal() -> None:
 	if not arch_config_handler.args.silent:
 		with Tui():
 			if not config.confirm_config():
-				debug('Installation aborted')
+				debug("Installation aborted")
 				_minimal()
 
 	if arch_config_handler.config.disk_config:
 		fs_handler = FilesystemHandler(
 			arch_config_handler.config.disk_config,
-			arch_config_handler.config.disk_encryption
+			arch_config_handler.config.disk_encryption,
 		)
 
 		fs_handler.perform_filesystem_operations()
