@@ -4,17 +4,17 @@ from .result import Result, ResultType
 from .types import Alignment, Chars, FrameProperties, FrameStyle, Orientation, PreviewStyle
 
 __all__ = [
-    'Alignment',
-    'Chars',
-    'EditMenu',
-    'FrameProperties',
-    'FrameStyle',
-    'MenuItem',
-    'MenuItemGroup',
-    'Orientation',
-    'PreviewStyle',
-    'Result',
-    'ResultType',
-    'SelectMenu',
-    'Tui',
+	"Alignment",
+	"Chars",
+	"EditMenu",
+	"FrameProperties",
+	"FrameStyle",
+	"MenuItem",
+	"MenuItemGroup",
+	"Orientation",
+	"PreviewStyle",
+	"Result",
+	"ResultType",
+	"SelectMenu",
+	"Tui",
 ]
